@@ -1,7 +1,7 @@
+use crate::config::option::SortType;
 use crate::context::AppContext;
 use crate::error::JoshutoResult;
 use crate::history::DirectoryHistory;
-use crate::util::sort::SortType;
 
 use super::reload;
 
