@@ -1,7 +1,7 @@
 use std::path;
 
 use crate::context::AppContext;
-use crate::error::JoshutoResult;
+use crate::error::{JoshutoError, JoshutoErrorKind, JoshutoResult};
 use crate::history::DirectoryHistory;
 use crate::tab::{JoshutoTab, TabHomePage};
 
@@ -33,10 +33,20 @@ fn _tab_switch(new_index: usize, context: &mut AppContext) -> std::io::Result<()
 
     let options = context.config_ref().display_options_ref().clone();
     let history = context.tab_context_mut().curr_tab_mut().history_mut();
-    history.create_or_soft_update(cwd.as_path(), &options)?;
+    if history
+        .create_or_soft_update(cwd.as_path(), &options)
+        .is_err()
+    {
+        history.remove(cwd.as_path());
+    }
 
     if let Some(file_path) = entry_path {
-        history.create_or_soft_update(file_path.as_path(), &options)?;
+        if history
+            .create_or_soft_update(file_path.as_path(), &options)
+            .is_err()
+        {
+            history.remove(file_path.as_path());
+        }
     }
 
     Ok(())
@@ -50,6 +60,22 @@ pub fn tab_switch(offset: i32, context: &mut AppContext) -> std::io::Result<()>
     _tab_switch(new_index, context)
 }
 
+pub fn tab_switch_index(new_index: usize, context: &mut AppContext) -> JoshutoResult<()> {
+    if new_index <= context.tab_context_ref().len() {
+        _tab_switch(new_index - 1, context)?;
+        Ok(())
+    } else if new_index == context.tab_context_ref().len() + 1 {
+        new_tab(context)?;
+        _tab_switch(new_index - 1, context)?;
+        Ok(())
+    } else {
+        Err(JoshutoError::new(
+            JoshutoErrorKind::InvalidParameters,
+            format!("No tab with index {}", new_index),
+        ))
+    }
+}
+
 pub fn new_tab_home_path(context: &AppContext) -> path::PathBuf {
     match context.config_ref().tab_options_ref().home_page() {
         TabHomePage::Home => match HOME_DIR.as_ref() {
