@@ -2,6 +2,7 @@ mod tui_dirlist;
 mod tui_dirlist_detailed;
 mod tui_file_preview;
 mod tui_footer;
+mod tui_help;
 mod tui_menu;
 mod tui_prompt;
 mod tui_tab;
@@ -13,6 +14,7 @@ pub use self::tui_dirlist::TuiDirList;
 pub use self::tui_dirlist_detailed::{trim_file_label, TuiDirListDetailed};
 pub use self::tui_file_preview::TuiFilePreview;
 pub use self::tui_footer::TuiFooter;
+pub use self::tui_help::{get_keymap_table, TuiHelp};
 pub use self::tui_menu::TuiMenu;
 pub use self::tui_prompt::TuiPrompt;
 pub use self::tui_tab::TuiTabBar;
